"""CTT Studio - Temporal resonance recording and analysis"""

from .studio import CTTStudio
from .audio import recorder
from .analysis import fft_processor
from .utils import constants

__version__ = "0.1.0"
__author__ = "Américo Simões"
__email__ = "amexsimoes@gmail.com"

PHI = (1 + 5**0.5) / 2
ALPHA = 0.0302011
ALPHA_RH = 0.0765872
