"""Audio recording module with temporal resonance detection"""

import numpy as np
import sounddevice as sd
from ..utils.constants import PHI, ALPHA

class TemporalRecorder:
    def __init__(self, sample_rate=44100):
        self.sr = sample_rate
        print("🎤 Temporal recorder initialized")
